==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/AzureFirewallApplicationRuleProtocolArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.AzureFirewallApplicationRuleProtocolType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the application rule protocol.
 * @property port Port number for the protocol, cannot be greater than 64000. This field is optional.
 * @property protocolType Protocol type.
 */
public data class AzureFirewallApplicationRuleProtocolArgs(
    public val port: Output<Int>? = null,
    public val protocolType: Output<Either<String, AzureFirewallApplicationRuleProtocolType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs =
        com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .protocolType(
                protocolType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureFirewallApplicationRuleProtocolArgs].
 */
@PulumiTagMarker
public class AzureFirewallApplicationRuleProtocolArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var protocolType: Output<Either<String, AzureFirewallApplicationRuleProtocolType>>? = null

    /**
     * @param value Port number for the protocol, cannot be greater than 64000. This field is optional.
     */
    @JvmName("eepykyhtcfppavgd")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("dpmyiouoelllgmht")
    public suspend
    fun protocolType(`value`: Output<Either<String, AzureFirewallApplicationRuleProtocolType>>) {
        this.protocolType = value
    }

    /**
     * @param value Port number for the protocol, cannot be greater than 64000. This field is optional.
     */
    @JvmName("scmqokupurfxqiad")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("llvhhkuiwjosynfx")
    public suspend
    fun protocolType(`value`: Either<String, AzureFirewallApplicationRuleProtocolType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("xkpwiuxfdpenhlit")
    public fun protocolType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureFirewallApplicationRuleProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("lekfgpwsksbynjre")
    public fun protocolType(`value`: AzureFirewallApplicationRuleProtocolType) {
        val toBeMapped = Either.ofRight<String, AzureFirewallApplicationRuleProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    internal fun build(): AzureFirewallApplicationRuleProtocolArgs =
        AzureFirewallApplicationRuleProtocolArgs(
            port = port,
            protocolType = protocolType,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/AzureFirewallApplicationRuleProtocolArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.AzureFirewallApplicationRuleProtocolType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the application rule protocol.
 * @property port Port number for the protocol, cannot be greater than 64000. This field is optional.
 * @property protocolType Protocol type.
 */
public data class AzureFirewallApplicationRuleProtocolArgs(
    public val port: Output<Int>? = null,
    public val protocolType: Output<Either<String, AzureFirewallApplicationRuleProtocolType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs =
        com.pulumi.azurenative.network.inputs.AzureFirewallApplicationRuleProtocolArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .protocolType(
                protocolType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureFirewallApplicationRuleProtocolArgs].
 */
@PulumiTagMarker
public class AzureFirewallApplicationRuleProtocolArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var protocolType: Output<Either<String, AzureFirewallApplicationRuleProtocolType>>? = null

    /**
     * @param value Port number for the protocol, cannot be greater than 64000. This field is optional.
     */
    @JvmName("wxgbsyiyjiygdhuf")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("sbddhrmyggjgkgnq")
    public suspend
    fun protocolType(`value`: Output<Either<String, AzureFirewallApplicationRuleProtocolType>>) {
        this.protocolType = value
    }

    /**
     * @param value Port number for the protocol, cannot be greater than 64000. This field is optional.
     */
    @JvmName("vqarubwkliwalonp")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("ytbwgauhqiiscldc")
    public suspend
    fun protocolType(`value`: Either<String, AzureFirewallApplicationRuleProtocolType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("kkrvyncvdgoebrfb")
    public fun protocolType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AzureFirewallApplicationRuleProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("yfkfkrpebunccivk")
    public fun protocolType(`value`: AzureFirewallApplicationRuleProtocolType) {
        val toBeMapped = Either.ofRight<String, AzureFirewallApplicationRuleProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    internal fun build(): AzureFirewallApplicationRuleProtocolArgs =
        AzureFirewallApplicationRuleProtocolArgs(
            port = port,
            protocolType = protocolType,
        )
}
